pub struct AgentConfig {
pub encoder: String,
pub head_layers: usize,
pub max_len: usize,
pub head_max_len: usize,
pub temperature: [f64; 3],
pub temperature_by_options: Vec<(String, f64)>,
}Expand description
Laya’s own config, rl_agent_config.json.
Fields
encoder: StringThe HF id of the encoder the checkpoint was trained from.
head_layers: usizeTransformer layers in the decision head.
max_len: usizeLongest sequence.
head_max_len: usizeBudget for the question head and its options.
temperature: [f64; 3]Per type temperatures, choice, score, noul.
temperature_by_options: Vec<(String, f64)>Temperatures per type and option count bucket, such as choice:3-5.
Implementations
Sourceimpl AgentConfig
impl AgentConfig